@@ -3,6 +3,7 @@ from os import mkdir
 from os.path import exists,abspath,join
 from subprocess import Popen,PIPE,STDOUT
 from cast_common.logger import Logger
+from pandas.api.types import is_numeric_dtype
 import sys
 
 __author__ = "Nevin Kaplan"
@@ -152,32 +153,37 @@ def format_table(writer, data, sheet_name,width=None):
 
     workbook = writer.book
     worksheet = writer.sheets[sheet_name]
-    rows = len(data)
+    rows = len(data)+1
     cols = len(data.columns)-1
+
     columns=[]
+    first=True
     for col_num, value in enumerate(data.columns.values):
-        columns.append({'header': value})
+        json = {'header': value}
+        if first:
+            first=False
+            json['total_string']='Totals'
+        else: 
+            if is_numeric_dtype(data[value]) and data[value].dtype != 'bool':
+                json['total_function']='sum'
+
+        columns.append(json)
 
     table_options={
+                'total_row':True,
                 'columns':columns,
                 'header_row':True,
                 'autofilter':True,
                 'banded_rows':True
                 }
     worksheet.add_table(0, 0, rows, cols,table_options)
-    
-    header_format = workbook.add_format({'text_wrap':True,
-                                        'align': 'center'})
 
     col_width = 10
     if width == None:
         width = []
         for i in range(1,len(data.columns)+1):
            width.append(col_width)
-    for col_num, value in enumerate(data.columns.values):
-        worksheet.write(0, col_num, value, header_format)
-        w=width[col_num]
-        worksheet.set_column(col_num, col_num, w)
+
     return worksheet
 
 # def format_table(writer, data, sheet_name,width=None):
